/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called 
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear 
 *    in their names without prior written permission of the 
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
package org.apache.ecs;

/**
    This class creates a &lt;A&gt; tag.
    <P>
    Please refer to the TestBed.java file for example code usage.

    @version $Id: A.java,v 1.2 1999/04/22 01:29:58 stephan Exp $
    @author <a href="mailto:snagy@servletapi.com">Stephan Nagy</a>
    @author <a href="mailto:jon@clearink.com">Jon S. Stevens</a>
*/
public class A extends MultiPartElement
{
    /**
          Private initialization routine.
     */
    {
        setElementType("a");
    }

    /**
        Basic constructor. You need to set the attributes using the
        set* methods.
    */
    public A()
    {
    }

    /**
        This constructor creates a &lt;A&gt; tag.

        @param   href  the URI that goes between double quotes
    */
    public A(String href)
    {
        setHref(href);
    }

    /**
        This constructor creates a &lt;A&gt; tag.
        
        @param   href  the URI that goes between double quotes
        @param   value what goes between &lt;start_tag&gt; &lt;end_tag&gt;
    */
    public A(String href, String value)
    {
        setHref(href);
        addElement(value);
    }

    /**
        This constructor creates a &lt;A&gt; tag.

        @param   href  the URI that goes between double quotes
        @param   value what goes between &lt;start_tag&gt; &lt;end_tag&gt;
    */
    public A(String href, Element value)
    {
        setHref(href);
        addElement(value);
    }

    /**
        This constructor creates a &lt;A&gt; tag.

        @param   href  the URI that goes between double quotes
        @param   name  the NAME="" attribute
        @param   value what goes between &lt;start_tag&gt; &lt;end_tag&gt;
    */
    public A(String href, String name, String value)
    {
        setHref(href);
        setName(name);
        addElement(value);
    }

    /**
        This constructor creates a &lt;A&gt; tag.

        @param   href  the URI that goes between double quotes
        @param   name  the NAME="" attribute
        @param   value what goes between &lt;start_tag&gt; &lt;end_tag&gt;
    */
    public A(String href, String name, Element value)
    {
        setHref(href);
        setName(name);
        addElement(value);
    }

    /**
        This constructor creates a &lt;A&gt; tag.

        @param   href  the URI that goes between double quotes
        @param   name  the NAME="" attribute
        @param   target  the TARGET="" attribute
        @param   value the value that goes between &lt;start_tag&gt; &lt;end_tag&gt;
    */
    public A(String href, String name, String target, Element value)
    {
        setHref(href);
        setName(name);
        setTarget(target);
        addElement(value);
    }

    /**
        This constructor creates a &lt;A&gt; tag.

        @param   href  the URI that goes between double quotes
        @param   name  the NAME="" attribute
        @param   target  the TARGET="" attribute
        @param   value the value that goes between &lt;start_tag&gt; &lt;end_tag&gt;
    */
    public A(String href, String name, String target, String value)
    {
        setHref(href);
        setName(name);
        setTarget(target);
        addElement(value);
    }

    /**
        This constructor creates a &lt;A&gt; tag.

        @param   href  the URI that goes between double quotes
        @param   name  the NAME="" attribute
        @param   target  the TARGET="" attribute
        @param   lang  the LANG="" attribute
        @param   value the value that goes between &lt;start_tag&gt; &lt;end_tag&gt;
    */
    public A(String href, String name, String target, String lang,
            String value)
    {
        setHref(href);
        setName(name);
        setTarget(target);
        setLang(lang);
        addElement(value);
    }

    /**
        This constructor creates a &lt;A&gt; tag.

        @param   href  the URI that goes between double quotes
        @param   name  the NAME="" attribute
        @param   target  the TARGET="" attribute
        @param   lang  the LANG="" attribute
        @param   value the value that goes between &lt;start_tag&gt; &lt;end_tag&gt;
    */
    public A(String href, String name, String target, String lang,
            Element value)
    {
        setHref(href);
        setName(name);
        setTarget(target);
        setLang(lang);
        addElement(value);
    }

    /**
        Sets the HREF="" attribute
        @param   href  the HREF="" attribute
    */
    public A setHref(String href)
    {
        addAttribute("href",href);
        return this;
    }

    /**
        Sets the NAME="" attribute
        @param   name  the NAME="" attribute
    */
    public A setName(String name)
    {
        addAttribute("name",name);
        return this;
    }

    /**
        Sets the TARGET="" attribute
        @param   target  the TARGET="" attribute
    */
    public A setTarget(String target)
    {
        addAttribute("target",target);
        return this;
    }

    /**
        Sets the REL="" attribute
        @param   rel  the REL="" attribute
    */
    public A setRel(String rel)
    {
        addAttribute("rel",rel);
        return this;
    }

    /**
        Sets the REV="" attribute
        @param   rev  the REV="" attribute
    */
    public A setRev(String rev)
    {
        addAttribute("rev",rev);
        return this;
    }

    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public A addElement(Element element)
    {
        addElementToRegistry(element,getFilterState());
        return(this);
    }
    /**
        Adds an Element to the element.
        @param  element Adds an Element to the element.
     */
    public A addElement(String element)
    {
        addElementToRegistry(element,getFilterState());
        return(this);
    }
}