/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called 
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear 
 *    in their names without prior written permission of the 
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
package org.apache.ecs;

/**
    This class creates a &lt;Input&gt; tag.

    @version $Id: Input.java,v 1.3 1999/04/22 01:35:05 stephan Exp $
    @author <a href="mailto:snagy@servletapi.com">Stephan Nagy</a>
    @author <a href="mailto:jon@clearink.com">Jon S. Stevens</a>
*/
public class Input extends SinglePartElement
{
    public static final String TEXT = "TEXT";
    public static final String PASSWORD = "PASSWORD";
    public static final String CHECKBOX = "CHECKBOX";
    public static final String RADIO = "RADIO";
    public static final String FILE = "FILE";
    public static final String BUTTON = "BUTTON";
    public static final String IMAGE = "IMAGE";
    public static final String HIDDEN = "HIDDEN";
    public static final String SUBMIT = "SUBMIT";
    public static final String RESET = "RESET";

    public static final String text = "text";
    public static final String password = "password";
    public static final String checkbox = "checkbox";
    public static final String radio = "radio";
    public static final String file = "file";
    public static final String button = "button";
    public static final String image = "image";
    public static final String hidden = "hidden";
    public static final String submit = "submit";
    public static final String reset = "reset";

    /**
        Private initialization routine.
    */
    {
        setElementType("input");
    }
    
    /**
        Basic constructor. Use the set* methods to set the values
        of the attributes.
    */
    public Input()
    {
    }
    
    /**
        Basic constructor. Use the set* methods to set the values
        of the attributes.
    */
    public Input(String type, String name, String value)
    {
        setType(type);
        setName(name);
        setValue(value);
    }

    /**
        Basic constructor. Use the set* methods to set the values
        of the attributes.
    */
    public Input(String type, String name, int value)
    {
        setType(type);
        setName(name);
        setValue(value);
    }

    /**
        Basic constructor. Use the set* methods to set the values
        of the attributes.
    */
    public Input(String type, String name, double value)
    {
        setType(type);
        setName(name);
        setValue(value);
    }

    /**
        Sets the TYPE="" attribute
        @param   type  the TYPE="" attribute
    */
    public Input setType(String type)
    {
        addAttribute("type",type);
        return this;
    }

    /**
        Sets the SRC="" attribute
        @param   src  the SRC="" attribute
    */
    public Input setSrc(String src)
    {
        addAttribute("src",src);
        return this;
    }

    /**
        Sets the ALT="" attribute
        @param   alt  the ALT="" attribute
    */
    public Input setAlt(String alt)
    {
        addAttribute("alt",alt);
        return this;
    }

    /**
        Sets the NAME="" attribute
        @param   name  the NAME="" attribute
    */
    public Input setName(String name)
    {
        addAttribute("name",name);
        return this;
    }
    
    /**
        Sets the VALUE="" attribute
        @param   value  the VALUE="" attribute
    */
    public Input setValue(String value)
    {
        addAttribute("value",value);
        return this;
    }
    
    /**
        Sets the VALUE="" attribute
        @param   value  the VALUE="" attribute
    */
    public Input setValue(int value)
    {
        addAttribute("value",Integer.toString(value));
        return this;
    }

    /**
        Sets the VALUE="" attribute
        @param   value  the VALUE="" attribute
    */
    public Input setValue(double value)
    {
        addAttribute("value",Double.toString(value));
        return this;
    }

    /**
        Sets the ACCEPT="" attribute
        @param   accept  the ACCEPT="" attribute
    */
    public Input setAccept(String accept)
    {
        addAttribute("accept",accept);
        return this;
    }
    
    /**
        Sets the SIZE="" attribute
        @param   size  the SIZE="" attribute
    */
    public Input setSize(String size)
    {
        addAttribute("size",size);
        return this;
    }
    
    /**
        Sets the SIZE="" attribute
        @param   size  the SIZE="" attribute
    */
    public Input setSize(int size)
    {
        setSize(Integer.toString(size));
        return this;
    }
    
    /**
        Sets the MAXLENGTH="" attribute
        @param   maxlength  the MAXLENGTH="" attribute
    */
    public Input setMaxlength(String maxlength)
    {
        addAttribute("maxlength",maxlength);
        return this;
    }
    
    /**
        Sets the MAXLENGTH="" attribute
        @param   maxlength  the MAXLENGTH="" attribute
    */
    public Input setMaxlength(int maxlength)
    {
        setMaxlength(Integer.toString(maxlength));
        return this;
    }
    
    /**
        Sets the USEMAP="" attribute
        @param   usemap  the USEMAP="" attribute
    */
    public Input setUsemap(String usemap)
    {
        addAttribute("usemap",usemap);
        return this;
    }
    
    /**
        Sets the TABINDEX="" attribute
        @param   alt  the TABINDEX="" attribute
    */
    public Input setTabindex(String index)
    {
        addAttribute("tabindex",index);
        return this;
    }
    
    /**
        Sets the TABINDEX="" attribute
        @param   alt  the TABINDEX="" attribute
    */
    public Input setTabindex(int index)
    {
        setTabindex(Integer.toString(index));
        return this;
    }
    
    /**
        Sets the checked value
        @param   checked  true or false
    */
    public Input setChecked(boolean checked)
    {
        if ( checked == true )
            addAttribute("checked", NO_ATTRIBUTE_VALUE);
        else
            removeAttribute("checked");
            
        return(this);
    }

    /**
        Sets the readonly value
        @param   readonly  true or false
    */
    public Input setReadOnly(boolean readonly)
    {
        if ( readonly == true )
            addAttribute("readonly", NO_ATTRIBUTE_VALUE);
        else
            removeAttribute("readonly");
            
        return(this);
    }

    /**
        Sets the disabled value
        @param   disabled  true or false
    */
    public Input setDisabled(boolean disabled)
    {
        if ( disabled == true )
            addAttribute("disabled", NO_ATTRIBUTE_VALUE);
        else
            removeAttribute("disabled");
            
        return(this);
    }
}